package com.mcwl.web.controller.communityCenter;


import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.utils.StringUtils;
import com.mcwl.communityCenter.service.InviteService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;

/**
 * 邀请
 */
@RestController
@RequestMapping("invite")
@RequiredArgsConstructor
public class InviteController {

    private final InviteService inviteService;

    /**
     * 邀请码链接
     */
    @GetMapping("inviteCode")
    public AjaxResult inviteCode(Long communityId) {
        // 获取邀请码链接
        String inviteCode = inviteService.getInviteCode(communityId);
        if (StringUtils.isBlank(inviteCode)) {
            return AjaxResult.warn("获取邀请码失败");
        }
        return AjaxResult.success(inviteCode);
    }

    /**
     * 接受邀请
     */
    @GetMapping("acceptInvite")
    public AjaxResult acceptInvite(@NotNull(message = "communityId不能为空") Long communityId,
                                   @NotBlank(message = "inviteCode不能为空") String inviteCode) {
        // 接受邀请
        boolean result = inviteService.acceptInvite(communityId, inviteCode);
        if (result) {
            return AjaxResult.success("接受邀请成功");
        }
        return AjaxResult.warn("接受邀请失败");
    }


}
